trait EvalContextPrivExt<'tcx>: MiriInterpCxExt<'tcx> {
// Provided methods
fn allocate_address_infos(
&mut self,
addresses: impl Iterator<Item = SocketAddr>,
) -> InterpResult<'tcx, Pointer> { ... }
fn free_address_infos(&mut self, address_ptr: Pointer) -> InterpResult<'tcx> { ... }
}Provided Methods
Sourcefn allocate_address_infos(
&mut self,
addresses: impl Iterator<Item = SocketAddr>,
) -> InterpResult<'tcx, Pointer>
fn allocate_address_infos( &mut self, addresses: impl Iterator<Item = SocketAddr>, ) -> InterpResult<'tcx, Pointer>
Allocate a linked list of address info structs from an iterator of SocketAddrs.
Returns a pointer pointing to the head of the linked list.
Sourcefn free_address_infos(&mut self, address_ptr: Pointer) -> InterpResult<'tcx>
fn free_address_infos(&mut self, address_ptr: Pointer) -> InterpResult<'tcx>
Deallocate the linked list of address info structs.
address_ptr points to the start from where we deallocate recursively.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".